jaraco.modb - Persistent objects in MongoDB
Author: Jason R. Coombs
Description: A framework for easily creating beautiful presentations using HTML

# jaraco.modb

### Persist Python objects in MongoDB

Created by Jason R. Coombs / @jaraco

## Goals

- Store and load arbitrary Python objects
- in centralized JSON store (MongoDB)

## Inspired by ZODB

### Heavily leverages jsonpickle

## Demo!

## So what?

HTTP Session objects

downstream models

anything you can imagine

## Limitations

- Integer keys
- Security
- Versioning
- Unpickleable objects

## Try it out

jaraco.modb